@@ -1,15 +1,19 @@
 import json
 
 from moto.core.responses import BaseResponse
-from .models import datapipeline_backends
+
+from .models import DataPipelineBackend, datapipeline_backends
 
 
 class DataPipelineResponse(BaseResponse):
-    @property
-    def datapipeline_backend(self):
-        return datapipeline_backends[self.region]
+    def __init__(self) -> None:
+        super().__init__(service_name="datapipeline")
 
-    def create_pipeline(self):
+    @property
+    def datapipeline_backend(self) -> DataPipelineBackend:
+        return datapipeline_backends[self.current_account][self.region]
+
+    def create_pipeline(self) -> str:
         name = self._get_param("name")
         unique_id = self._get_param("uniqueId")
         description = self._get_param("description", "")
@@ -19,7 +23,7 @@ class DataPipelineResponse(BaseResponse):
         )
         return json.dumps({"pipelineId": pipeline.pipeline_id})
 
-    def list_pipelines(self):
+    def list_pipelines(self) -> str:
         pipelines = list(self.datapipeline_backend.list_pipelines())
         pipeline_ids = [pipeline.pipeline_id for pipeline in pipelines]
         max_pipelines = 50
@@ -44,7 +48,7 @@ class DataPipelineResponse(BaseResponse):
             }
         )
 
-    def describe_pipelines(self):
+    def describe_pipelines(self) -> str:
         pipeline_ids = self._get_param("pipelineIds")
         pipelines = self.datapipeline_backend.describe_pipelines(pipeline_ids)
 
@@ -52,19 +56,19 @@ class DataPipelineResponse(BaseResponse):
             {"pipelineDescriptionList": [pipeline.to_json() for pipeline in pipelines]}
         )
 
-    def delete_pipeline(self):
+    def delete_pipeline(self) -> str:
         pipeline_id = self._get_param("pipelineId")
         self.datapipeline_backend.delete_pipeline(pipeline_id)
         return json.dumps({})
 
-    def put_pipeline_definition(self):
+    def put_pipeline_definition(self) -> str:
         pipeline_id = self._get_param("pipelineId")
         pipeline_objects = self._get_param("pipelineObjects")
 
         self.datapipeline_backend.put_pipeline_definition(pipeline_id, pipeline_objects)
         return json.dumps({"errored": False})
 
-    def get_pipeline_definition(self):
+    def get_pipeline_definition(self) -> str:
         pipeline_id = self._get_param("pipelineId")
         pipeline_definition = self.datapipeline_backend.get_pipeline_definition(
             pipeline_id
@@ -77,7 +81,7 @@ class DataPipelineResponse(BaseResponse):
             }
         )
 
-    def describe_objects(self):
+    def describe_objects(self) -> str:
         pipeline_id = self._get_param("pipelineId")
         object_ids = self._get_param("objectIds")
 
@@ -94,7 +98,7 @@ class DataPipelineResponse(BaseResponse):
             }
         )
 
-    def activate_pipeline(self):
+    def activate_pipeline(self) -> str:
         pipeline_id = self._get_param("pipelineId")
         self.datapipeline_backend.activate_pipeline(pipeline_id)
         return json.dumps({})
