@@ -1,23 +1,24 @@
 import ipaddress
 from typing import Any, Dict, List, Optional, Set
 
-from moto.core import CloudFormationModel
+from moto.core.common_models import CloudFormationModel
 from moto.ec2.models.carrier_gateways import CarrierGateway
 from moto.ec2.models.elastic_network_interfaces import NetworkInterface
-from moto.ec2.models.internet_gateways import EgressOnlyInternetGateway
 from moto.ec2.models.instances import Instance
+from moto.ec2.models.internet_gateways import EgressOnlyInternetGateway
 from moto.ec2.models.managed_prefixes import ManagedPrefixList
 from moto.ec2.models.nat_gateways import NatGateway
 from moto.ec2.models.transit_gateway import TransitGateway
 from moto.ec2.models.vpc_peering_connections import VPCPeeringConnection
 from moto.ec2.models.vpn_gateway import VpnGateway
-from .core import TaggedEC2Resource
+
 from ..exceptions import (
     DependencyViolationError,
-    InvalidRouteError,
-    InvalidRouteTableIdError,
     InvalidAssociationIdError,
     InvalidDestinationCIDRBlockParameterError,
+    InvalidParameterValueErrorReplaceRoute,
+    InvalidRouteError,
+    InvalidRouteTableIdError,
     RouteAlreadyExistsError,
     RouteNotSupportedError,
 )
@@ -25,9 +26,10 @@ from ..utils import (
     EC2_RESOURCE_TO_PREFIX,
     generate_route_id,
     generic_filter,
-    random_subnet_association_id,
     random_route_table_id,
+    random_subnet_association_id,
 )
+from .core import TaggedEC2Resource
 
 
 class RouteTable(TaggedEC2Resource, CloudFormationModel):
@@ -114,6 +116,18 @@ class RouteTable(TaggedEC2Resource, CloudFormationModel):
                 for route in self.routes.values()
                 if route.vpc_pcx is not None
             ]
+        elif filter_name == "route.nat-gateway-id":
+            return [
+                route.nat_gateway.id
+                for route in self.routes.values()
+                if route.nat_gateway is not None
+            ]
+        elif filter_name == "route.transit-gateway-id":
+            return [
+                route.transit_gateway.id
+                for route in self.routes.values()
+                if route.transit_gateway is not None
+            ]
         else:
             return super().get_filter_value(filter_name, "DescribeRouteTables")
 
@@ -447,11 +461,22 @@ class RouteBackend:
         interface_id: Optional[str] = None,
         vpc_peering_connection_id: Optional[str] = None,
     ) -> Route:
+        cidr = destination_cidr_block
+        if destination_ipv6_cidr_block:
+            cidr = destination_ipv6_cidr_block
+        if destination_prefix_list_id:
+            cidr = destination_prefix_list_id
         route_table = self.get_route_table(route_table_id)
         route_id = generate_route_id(
             route_table.id, destination_cidr_block, destination_ipv6_cidr_block
         )
-        route = route_table.routes[route_id]
+        try:
+            route = route_table.routes[route_id]
+        except KeyError:
+            # This should be 'raise InvalidRouteError(route_table_id, cidr)' in
+            # line with the delete_route() equivalent, but for some reason AWS
+            # returns InvalidParameterValue instead in this case.
+            raise InvalidParameterValueErrorReplaceRoute(cidr) from None
 
         route.gateway = None
         route.nat_gateway = None
@@ -475,7 +500,9 @@ class RouteBackend:
             )
 
         route.instance = self.get_instance(instance_id) if instance_id else None  # type: ignore[attr-defined]
-        route.interface = self.get_network_interface(interface_id) if interface_id else None  # type: ignore[attr-defined]
+        route.interface = (
+            self.get_network_interface(interface_id) if interface_id else None  # type: ignore[attr-defined]
+        )
         route.vpc_pcx = (
             self.get_vpc_peering_connection(vpc_peering_connection_id)  # type: ignore[attr-defined]
             if vpc_peering_connection_id
