@@ -38,10 +38,10 @@ class QueueAlreadyExists(RESTError):
 class EmptyBatchRequest(RESTError):
     code = 400
 
-    def __init__(self) -> None:
+    def __init__(self, action: str = "Send") -> None:
         super().__init__(
-            "EmptyBatchRequest",
-            "There should be at least one SendMessageBatchRequestEntry in the request.",
+            "AWS.SimpleQueueService.EmptyBatchRequest",
+            f"There should be at least one {action}MessageBatchRequestEntry in the request.",
         )
 
 
