@@ -45,3 +45,18 @@ class ResourceNotFound(AWSError):
 
     def __init__(self, arn: str):
         super().__init__(f"Resource not found: '{arn}'")
+
+
+class ValidationException(AWSError):
+    TYPE = "ValidationException"
+
+    def __init__(self, msg: str):
+        super().__init__(msg)
+
+
+class NameTooLongException(ValidationException):
+    def __init__(self, name: str):
+        super().__init__(
+            f"1 validation error detected: Value '{name}' at 'name' "
+            "failed to satisfy constraint: Member must have length less than or equal to 80"
+        )
